@@ -1,9 +1,10 @@
 import logging
+from datetime import datetime, timedelta
 
 from django.conf import settings
 from django.db import models
 from django.contrib.contenttypes.fields import GenericForeignKey, ContentType
-from django.utils.timezone import datetime, make_aware
+from django.utils.timezone import make_aware
 
 from datagrowth import configuration
 
@@ -41,10 +42,12 @@ class Resource(models.Model):
         ordering = ("id",)
 
     def clean(self):
-        if len(self.uri):
+        if self.uri and len(self.uri):
             self.uri = self.uri[:255]
         if not self.id and self.config.purge_immediately:
             self.purge_at = make_aware(datetime.now())
+        if not self.purge_at and self.config.purge_after:
+            self.purge_at = make_aware(datetime.now()) + timedelta(**self.config.purge_after)
 
     #######################################################
     # RESOURCE INTERFACE
